@@ -1,7 +1,7 @@
 pred.senv <- function (m, Xnew) 
 {
   if (is.null(m$ratio)) 
-    stop("The asymptotic distribution part of env is missing. Rerun env with asy = T")
+    stop("The asymptotic distribution part of senv is missing. Rerun senv with asy = T")
   r <- ncol(m$Sigma)
   n <- m$n
   if (is.null(m$Gamma)) {
@@ -30,4 +30,4 @@ pred.senv <- function (m, Xnew)
   SE.pred <- sqrt(diag(covMatrix.pred))
   return(list(value = value, covMatrix.estm = covMatrix.estm, 
               SE.estm = SE.estm, covMatrix.pred = covMatrix.pred, SE.pred = SE.pred))
-}
\ No newline at end of file
+}
